import { createRouter, createWebHashHistory } from 'vue-router'
import UserLayout from '@/layout/user-layout.vue'
import AdminLayout from '@/layout/admin-layout.vue'
import BlankLayout from '@/layout/blank-layout.vue'

export const routes = [
	{
		path: '/admin/acl',  // 系统管理
		name: 'ACL',
		meta: { title: 'menus.acl.name', icon: 'icon-acl', flat: true },
		component: BlankLayout,
		redirect: () => ({ name: 'Users' }),
		children: [
			{
				path: '/admin/acl/users', //用户列表
				name: 'Users',
				meta: { title: 'menus.acl.users', icon: 'icon-user' },
				component: () => import('../views/admin/acl/users/user-list.vue'),
			},
			{
				path: '/admin/acl/role', // 角色列表
				name: 'Role',
				meta: { title: 'menus.acl.role', icon: 'icon-role' },
				component: () => import('../views/admin/acl/role/role-list.vue'),
			},
			{
				path: '/admin/acl/permission', //权限
				name: 'Permission',
				meta: { title: 'menus.acl.permission', icon: 'icon-permission' },
				component: () => import('../views/admin/acl/permission/permission-management.vue'),
			},
			{
				path: '/admin/acl/material', //物料
				name: 'Material',
				meta: {title: 'menus.acl.material',icon: 'icon-permission'},
				component: ()=> import('../views/stock/material/material-page.vue'),
			}
		],
	},
	{
		path: '/stock/name',  // 库存管理
		name: 'STOCK',
		meta: { title: 'menus.stock.name', icon: 'icon-acl', flat: true },
		component: BlankLayout,
		redirect: () => ({ name: 'Inbound' }),
		children: [
			{
				path: '/stock/inbound', //入库
				name: 'Inbound',
				meta: {title: '入库申请',icon: 'icon-permission'},
				component: ()=> import('../../src/views/stock/inboud/inboud-page.vue'),  // 好奇怪，新创建的文件，要多向上找一层才不会报错
			},
			{
				path: '/stock/outbound', //出库
				name: 'Outbound',
				meta: {title: '出库申请',icon: 'icon-permission'},
				component: ()=> import('../views/admin/sensor/sensor-page.vue'),
			},
			{
				path: '/stock/inventory', //盘点
				name: 'Inventory',
				meta: {title: '盘点申请',icon: 'icon-permission'},
				component: ()=> import('../views/admin/sensor/sensor-page.vue')
			},
		]
	},
	{
		path: '/statistic/name',  // 统计报表
		name: 'STATISTIC',
		meta: { title: 'menus.statistic.name', icon: 'icon-acl', flat: true },
		component: BlankLayout,
		redirect: () => ({ name: 'S-Inbound' }),
		children: [
			{
				path: '/statistic/inbound', //入库
				name: 'S-Inbound',
				meta: {title: 'menus.statistic.inbound',icon: 'icon-permission'},
				component: ()=> import('../views/admin/sensor/sensor-page.vue'),
			},
			{
				path: '/statistic/outbound', //出库
				name: 'S-Outbound',
				meta: {title: 'menus.statistic.outbound',icon: 'icon-permission'},
				component: ()=> import('../views/admin/sensor/sensor-page.vue'),
			},
			{
				path: '/statistic/inventory', //盘点
				name: 'S-Inventory',
				meta: {title: 'menus.statistic.inventory',icon: 'icon-permission'},
				component: ()=> import('../views/admin/sensor/sensor-page.vue'),
			},
		]
	}
]

export default createRouter({
	history: createWebHashHistory(),
	routes: [
		{
			path: '/',
			name: 'Index',
			redirect: '/login',
		},
		{
			path: '/dashboard',
			name: 'Dashboard',
			component: () => import('../views/dashboard/dashboard-page.vue'),
		},
		{
			path: '/login',
			name: 'Login',
			redirect: '/login/user',
			component: UserLayout,
			children: [
				{
					path: 'user',
					name: 'LoginPage',
					component: () => import('../views/login/user-login.vue'),
				},
			],
		},
		{
			path: '/admin',
			name: 'Admin',
			redirect: '/admin/dashboard',
			component: AdminLayout,
			meta: { title: 'menus.index', icon: 'icon-home' },
			children: routes,
		},
		{
			path: '/:catchAll(.*)',
			redirect: '/message',
		},
		{
			path: '/message',
			name: 'Message',
			component: () => import('@/views/message/message-page.vue'),
		},
	],
})
